@@ -1,6 +1,6 @@
 package Defaults::Modern;
 {
-  $Defaults::Modern::VERSION = '0.005001';
+  $Defaults::Modern::VERSION = '0.005002';
 }
 use v5.14;
 
@@ -92,8 +92,8 @@ sub import {
   };
 
   state $fp_defaults = +{
+    strict                => 1,
     default_arguments     => 1,
-    check_argument_count  => 1,
     named_parameters      => 1,
     types                 => 1,
     reify_type            => $reify,
@@ -107,7 +107,7 @@ sub import {
       },
       method => {
         name                  => 'required',
-        attrs                 => ':method',
+        attributes            => ':method',
         shift                 => '$self',
         invocant              => 1,
         %$fp_defaults
